@@ -2,12 +2,17 @@ package Sereal;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION = '0.370';
-use Sereal::Encoder 0.37 qw(encode_sereal);
-use Sereal::Decoder 0.37 qw(decode_sereal looks_like_sereal);
+our $VERSION = '2.070_101';
+use Sereal::Encoder 2.070_101 qw(encode_sereal sereal_encode_with_object);
+use Sereal::Decoder 2.070_101 qw(decode_sereal looks_like_sereal sereal_decode_with_object);
 
 use Exporter 'import';
-our @EXPORT_OK = qw(encode_sereal decode_sereal looks_like_sereal);
+our @EXPORT_OK = qw(
+  encode_sereal decode_sereal
+  looks_like_sereal
+  sereal_encode_with_object
+  sereal_decode_with_object
+);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
 our @EXPORT = ((caller())[1] eq '-e' ? @EXPORT_OK : ());
@@ -24,8 +29,15 @@ Sereal - Fast, compact, powerful binary (de-)serialization
 
 =head1 SYNOPSIS
 
-  use Sereal qw(encode_sereal decode_sereal looks_like_sereal);
-  
+  use Sereal qw(encode_sereal decode_sereal
+                sereal_encode_with_object
+                sereal_decode_with_object
+                looks_like_sereal);
+  # Note: For performance reasons, you should prefer the OO interface,
+  #       or sereal_(en|de)code_with_object over the stateless
+  #       encode_sereal/decode_sereal functions.
+  #       See the Sereal::Performance documentation for details.
+
 =head1 DESCRIPTION
 
 I<Sereal> is an efficient, compact-output, binary and feature-rich
@@ -54,17 +66,34 @@ L<https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs>.
 
 It is recommended to use the object-oriented interface of
 C<Sereal::Encoder> and C<Sereal::Decoder> if you care about
-performance.
+performance. For detailed performance considerations,
+see L<Sereal::Performance>.
 
-You can optionally import three functions from C<Sereal>.
+You can optionally import five functions from C<Sereal>.
 C<encode_sereal> is the same function as L<Sereal::Encoder>'s
 C<encode_sereal> function. C<decode_sereal> and C<looks_like_sereal>
 are the same as L<Sereal::Decoder>'s functions of the same names.
+Finally, you can import the advanced functional interface
+C<sereal_encode_with_object> and C<sereal_decode_with_object>.
+Again, see L<Sereal::Performance> for information about those.
 
 After loading the C<Sereal> module, both C<Sereal::Encoder> and
 C<Sereal::Decoder> are guaranteed to be loaded, so you can use
 their object-oriented interface.
 
+=head1 BUGS, CONTACT AND SUPPORT
+
+For reporting bugs, please use the github bug tracker at
+L<http://github.com/Sereal/Sereal/issues>.
+
+For support and discussion of Sereal, there are two Google Groups:
+
+Announcements around Sereal (extremely low volume):
+L<https://groups.google.com/forum/?fromgroups#!forum/sereal-announce>
+
+Sereal development list:
+L<https://groups.google.com/forum/?fromgroups#!forum/sereal-dev>
+
 =head1 AUTHOR
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
@@ -78,6 +107,6 @@ their gratitude.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012, 2013 by Steffen Mueller
+Copyright (C) 2012, 2013, 2014 by Steffen Mueller
 
 =cut
